@@ -1,6 +1,6 @@
 /*
  * iostat: report CPU and I/O statistics
- * (C) 1998-2016 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1998-2017 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -87,13 +87,13 @@ void usage(char *progname)
 		progname);
 #ifdef DEBUG
 	fprintf(stderr, _("Options are:\n"
-			  "[ -c ] [ -d ] [ -h ] [ -k | -m ] [ -N ] [ -t ] [ -V ] [ -x ] [ -y ] [ -z ]\n"
+			  "[ -c ] [ -d ] [ -h ] [ -k | -m ] [ -N ] [ -s ] [ -t ] [ -V ] [ -x ] [ -y ] [ -z ]\n"
 			  "[ -j { ID | LABEL | PATH | UUID | ... } ] [ --human ] [ -o JSON ]\n"
 			  "[ [ -H ] -g <group_name> ] [ -p [ <device> [,...] | ALL ] ]\n"
 			  "[ <device> [...] | ALL ] [ --debuginfo ]\n"));
 #else
 	fprintf(stderr, _("Options are:\n"
-			  "[ -c ] [ -d ] [ -h ] [ -k | -m ] [ -N ] [ -t ] [ -V ] [ -x ] [ -y ] [ -z ]\n"
+			  "[ -c ] [ -d ] [ -h ] [ -k | -m ] [ -N ] [ -s ] [ -t ] [ -V ] [ -x ] [ -y ] [ -z ]\n"
 			  "[ -j { ID | LABEL | PATH | UUID | ... } ] [ --human ] [ -o JSON ]\n"
 			  "[ [ -H ] -g <group_name> ] [ -p [ <device> [,...] | ALL ] ]\n"
 			  "[ <device> [...] | ALL ]\n"));
@@ -854,7 +854,7 @@ void write_plain_cpu_stat(int curr, unsigned long long itv)
 	printf("avg-cpu:  %%user   %%nice %%system %%iowait  %%steal   %%idle\n");
 
 	printf("       ");
-	cprintf_pc(6, 7, 2,
+	cprintf_pc(DISPLAY_UNIT(flags), 6, 7, 2,
 		   ll_sp_value(st_cpu[!curr]->cpu_user,   st_cpu[curr]->cpu_user,   itv),
 		   ll_sp_value(st_cpu[!curr]->cpu_nice,   st_cpu[curr]->cpu_nice,   itv),
 		   /*
@@ -950,21 +950,38 @@ void write_disk_stat_header(int *fctr, int *tab)
 
 	if (DISPLAY_EXTENDED(flags)) {
 		/* Extended stats */
-		printf("Device:         rrqm/s   wrqm/s     r/s     w/s");
-		if (DISPLAY_MEGABYTES(flags)) {
-			printf("    rMB/s    wMB/s");
-		}
-		else if (DISPLAY_KILOBYTES(flags)) {
-			printf("    rkB/s    wkB/s");
+		printf("Device       ");
+		if (DISPLAY_SHORT_OUTPUT(flags)) {
+			printf("      tps");
+			if (DISPLAY_MEGABYTES(flags)) {
+				printf("      MB/s");
+			}
+			else if (DISPLAY_KILOBYTES(flags)) {
+				printf("      kB/s");
+			}
+			else {
+				printf("     sec/s");
+			}
+			printf("    rqm/s   await aqu-sz  areq-sz  %%util\n");
 		}
 		else {
-			printf("   rsec/s   wsec/s");
+			printf("     r/s     w/s");
+			if (DISPLAY_MEGABYTES(flags)) {
+				printf("     rMB/s     wMB/s");
+			}
+			else if (DISPLAY_KILOBYTES(flags)) {
+				printf("     rkB/s     wkB/s");
+			}
+			else {
+				printf("    rsec/s    wsec/s");
+			}
+			printf("   rrqm/s   wrqm/s  %%rrqm  %%wrqm r_await w_await"
+			       " aqu-sz rareq-sz wareq-sz  svctm  %%util\n");
 		}
-		printf(" avgrq-sz avgqu-sz   await r_await w_await  svctm  %%util\n");
 	}
 	else {
 		/* Basic stats */
-		printf("Device:            tps");
+		printf("Device             tps");
 		if (DISPLAY_KILOBYTES(flags)) {
 			printf("    kB_read/s    kB_wrtn/s    kB_read    kB_wrtn\n");
 		}
@@ -990,17 +1007,14 @@ void write_disk_stat_header(int *fctr, int *tab)
  * @ioj		Previous sample statistics.
  * @devname	Current device name.
  * @xds		Extended stats for current device.
- * @r_await	r_await metric value.
- * @w_await	w_await metric value.
+ * @xios	Additional extended statistics for current device.
  ***************************************************************************
  */
 void write_plain_ext_stat(unsigned long long itv, int fctr,
 			  struct io_hdr_stats *shi, struct io_stats *ioi,
 			  struct io_stats *ioj, char *devname, struct ext_disk_stats *xds,
-			  double r_await, double w_await)
+			  struct ext_io_stats *xios)
 {
-	double rsectors, wsectors;
-
 	if (DISPLAY_HUMAN_READ(flags)) {
 		cprintf_in(IS_STR, "%s\n", devname, 0);
 		printf("%13s", "");
@@ -1009,36 +1023,80 @@ void write_plain_ext_stat(unsigned long long itv, int fctr,
 		cprintf_in(IS_STR, "%-13s", devname, 0);
 	}
 
-	/*       rrq/s wrq/s   r/s   w/s  rsec  wsec  rqsz  qusz await r_await w_await svctm %util */
-	cprintf_f(-1, 2, 8, 2,
-		  S_VALUE(ioj->rd_merges, ioi->rd_merges, itv),
-		  S_VALUE(ioj->wr_merges, ioi->wr_merges, itv));
-	cprintf_f(-1, 2, 7, 2,
-		  S_VALUE(ioj->rd_ios, ioi->rd_ios, itv),
-		  S_VALUE(ioj->wr_ios, ioi->wr_ios, itv));
-	rsectors = S_VALUE(ioj->rd_sectors, ioi->rd_sectors, itv);
-	wsectors = S_VALUE(ioj->wr_sectors, ioi->wr_sectors, itv);
-	if (!DISPLAY_UNIT(flags)) {
-		rsectors /= fctr;
-		wsectors /= fctr;
+	if (DISPLAY_SHORT_OUTPUT(flags)) {
+		/* tps */
+		cprintf_f(NO_UNIT, 1, 8, 2,
+			  S_VALUE(ioj->rd_ios + ioj->wr_ios, ioi->rd_ios + ioi->wr_ios, itv));
+		/* kB/s */
+		if (!DISPLAY_UNIT(flags)) {
+			xios->sectors /= fctr;
+		}
+		cprintf_f(DISPLAY_UNIT(flags) ? UNIT_SECTOR : NO_UNIT, 1, 9, 2,
+			  xios->sectors);
+		/* rqm/s */
+		cprintf_f(NO_UNIT, 1, 8, 2,
+			  S_VALUE(ioj->rd_merges + ioj->wr_merges, ioi->rd_merges + ioi->wr_merges, itv));
+		/* await */
+		cprintf_f(NO_UNIT, 1, 7, 2,
+			  xds->await);
+		/* aqu-sz */
+		cprintf_f(NO_UNIT, 1, 6, 2,
+			  S_VALUE(ioj->rq_ticks, ioi->rq_ticks, itv) / 1000.0);
+		/* areq-sz (in kB, not sectors) */
+		cprintf_f(DISPLAY_UNIT(flags) ? UNIT_KILOBYTE : NO_UNIT, 1, 8, 2,
+			  xds->arqsz / 2);
+		/*
+		 * %util
+		 * Again: Ticks in milliseconds.
+		 * In the case of a device group (option -g), shi->used is the number of
+		 * devices in the group. Else shi->used equals 1.
+		 */
+		cprintf_pc(DISPLAY_UNIT(flags), 1, 6, 2,
+			   shi->used ? xds->util / 10.0 / (double) shi->used
+				     : xds->util / 10.0);	/* shi->used should never be zero here */
+		printf("\n");
+	}
+	else {
+		/* r/s  w/s */
+		cprintf_f(NO_UNIT, 2, 7, 2,
+			  S_VALUE(ioj->rd_ios, ioi->rd_ios, itv),
+			  S_VALUE(ioj->wr_ios, ioi->wr_ios, itv));
+		/* rkB/s  wkB/s */
+		if (!DISPLAY_UNIT(flags)) {
+			xios->rsectors /= fctr;
+			xios->wsectors /= fctr;
+		}
+		cprintf_f(DISPLAY_UNIT(flags) ? UNIT_SECTOR : NO_UNIT, 2, 9, 2,
+			  xios->rsectors, xios->wsectors);
+		/* rrqm/s  wrqm/s */
+		cprintf_f(NO_UNIT, 2, 8, 2,
+			  S_VALUE(ioj->rd_merges, ioi->rd_merges, itv),
+			  S_VALUE(ioj->wr_merges, ioi->wr_merges, itv));
+		/* %rrqm  %wrqm */
+		cprintf_pc(DISPLAY_UNIT(flags), 2, 6, 2,
+			   xios->rrqm_pc, xios->wrqm_pc);
+		/* r_await  w_await */
+		cprintf_f(NO_UNIT, 2, 7, 2,
+			  xios->r_await, xios->w_await);
+		/* aqu-sz */
+		cprintf_f(NO_UNIT, 1, 6, 2,
+			  S_VALUE(ioj->rq_ticks, ioi->rq_ticks, itv) / 1000.0);
+		/* rareq-sz  wareq-sz (in kB, not sectors) */
+		cprintf_f(DISPLAY_UNIT(flags) ? UNIT_KILOBYTE : NO_UNIT, 2, 8, 2,
+			  xios->rarqsz / 2, xios->warqsz / 2);
+		/* svctm - The ticks output is biased to output 1000 ticks per second */
+		cprintf_f(NO_UNIT, 1, 6, 2, xds->svctm);
+		/*
+		 * %util
+		 * Again: Ticks in milliseconds.
+		 * In the case of a device group (option -g), shi->used is the number of
+		 * devices in the group. Else shi->used equals 1.
+		 */
+		cprintf_pc(DISPLAY_UNIT(flags), 1, 6, 2,
+			   shi->used ? xds->util / 10.0 / (double) shi->used
+				     : xds->util / 10.0);	/* shi->used should never be zero here */
+		printf("\n");
 	}
-	cprintf_f(DISPLAY_UNIT(flags) ? 0 : -1, 2, 8, 2,
-		  rsectors, wsectors);
-	cprintf_f(-1, 2, 8, 2,
-		  xds->arqsz,
-		  S_VALUE(ioj->rq_ticks, ioi->rq_ticks, itv) / 1000.0);
-	cprintf_f(-1, 3, 7, 2, xds->await, r_await, w_await);
-	/* The ticks output is biased to output 1000 ticks per second */
-	cprintf_f(-1, 1, 6, 2, xds->svctm);
-	/*
-	 * Again: Ticks in milliseconds.
-	 * In the case of a device group (option -g), shi->used is the number of
-	 * devices in the group. Else shi->used equals 1.
-	 */
-	cprintf_pc(1, 6, 2,
-		   shi->used ? xds->util / 10.0 / (double) shi->used
-		             : xds->util / 10.0);	/* shi->used should never be zero here */
-	printf("\n");
 }
 
 /*
@@ -1055,34 +1113,71 @@ void write_plain_ext_stat(unsigned long long itv, int fctr,
  * @ioj		Previous sample statistics.
  * @devname	Current device name.
  * @xds		Extended stats for current device.
- * @r_await	r_await metric value.
- * @w_await	w_await metric value.
+ * @xios	Additional extended statistics for current device.
  ***************************************************************************
  */
 void write_json_ext_stat(int tab, unsigned long long itv, int fctr,
-		    struct io_hdr_stats *shi, struct io_stats *ioi,
-		    struct io_stats *ioj, char *devname, struct ext_disk_stats *xds,
-		    double r_await, double w_await)
+			 struct io_hdr_stats *shi, struct io_stats *ioi,
+			 struct io_stats *ioj, char *devname, struct ext_disk_stats *xds,
+			 struct ext_io_stats *xios)
 {
+	char line[256];
+
 	xprintf0(tab,
-		 "{\"disk_device\": \"%s\", \"rrqm\": %.2f, \"wrqm\": %.2f, "
-		 "\"r\": %.2f, \"w\": %.2f, \"rkB\": %.2f, \"wkB\": %.2f, "
-		 "\"avgrq-sz\": %.2f, \"avgqu-sz\": %.2f, "
-		 "\"await\": %.2f, \"r_await\": %.2f, \"w_await\": %.2f, "
-		 "\"svctm\": %.2f, \"util\": %.2f}",
-		 devname,
-		 S_VALUE(ioj->rd_merges, ioi->rd_merges, itv),
-		 S_VALUE(ioj->wr_merges, ioi->wr_merges, itv),
-		 S_VALUE(ioj->rd_ios, ioi->rd_ios, itv),
-		 S_VALUE(ioj->wr_ios, ioi->wr_ios, itv),
-		 S_VALUE(ioj->rd_sectors, ioi->rd_sectors, itv) / fctr,
-		 S_VALUE(ioj->wr_sectors, ioi->wr_sectors, itv) / fctr,
-		 xds->arqsz,
-		 S_VALUE(ioj->rq_ticks, ioi->rq_ticks, itv) / 1000.0,
-		 xds->await,
-		 r_await,
-		 w_await,
-		 xds->svctm,
+		 "{\"disk_device\": \"%s\", ",
+		 devname);
+
+	if (DISPLAY_SHORT_OUTPUT(flags)) {
+		printf("\"tps\": %.2f, \"",
+		       S_VALUE(ioj->rd_ios + ioj->wr_ios, ioi->rd_ios + ioi->wr_ios, itv));
+		if (DISPLAY_MEGABYTES(flags)) {
+			printf("MB/s");
+		}
+		else if (DISPLAY_KILOBYTES(flags)) {
+			printf("kB/s");
+		}
+		else {
+			printf("sec/s");
+		}
+		printf("\": %.2f, \"rqm/s\": %.2f, \"await\": %.2f, "
+		       "\"aqu-sz\": %.2f, \"areq-sz\": %.2f, ",
+		       xios->sectors /= fctr,
+		       S_VALUE(ioj->rd_merges + ioj->wr_merges, ioi->rd_merges + ioi->wr_merges, itv),
+		       xds->await,
+		       S_VALUE(ioj->rq_ticks, ioi->rq_ticks, itv) / 1000.0,
+		       xds->arqsz / 2);
+	}
+	else {
+		printf("\"r/s\": %.2f, \"w/s\": %.2f, ",
+		       S_VALUE(ioj->rd_ios, ioi->rd_ios, itv),
+		       S_VALUE(ioj->wr_ios, ioi->wr_ios, itv));
+		if (DISPLAY_MEGABYTES(flags)) {
+			sprintf(line, "\"rMB/s\": %%.2f, \"wMB/s\": %%.2f, ");
+		}
+		else if (DISPLAY_KILOBYTES(flags)) {
+			sprintf(line, "\"rkB/s\": %%.2f, \"wkB/s\": %%.2f, ");
+		}
+		else {
+			sprintf(line, "\"rsec/s\": %%.2f, \"wsec/s\": %%.2f, ");
+		}
+		printf(line,
+		       xios->rsectors /= fctr,
+		       xios->wsectors /= fctr);
+		printf("\"rrqm/s\": %.2f, \"wrqm/s\": %.2f, \"rrqm\": %.2f, \"wrqm\": %.2f, "
+		       "\"r_await\": %.2f, \"w_await\": %.2f, "
+		       "\"aqu-sz\": %.2f, \"rareq-sz\": %.2f, \"wareq-sz\": %.2f,  \"svctm\": %.2f, ",
+		       S_VALUE(ioj->rd_merges, ioi->rd_merges, itv),
+		       S_VALUE(ioj->wr_merges, ioi->wr_merges, itv),
+		       xios->rrqm_pc,
+		       xios->wrqm_pc,
+		       xios->r_await,
+		       xios->w_await,
+		       S_VALUE(ioj->rq_ticks, ioi->rq_ticks, itv) / 1000.0,
+		       xios->rarqsz / 2,
+		       xios->warqsz / 2,
+		       xds->svctm);
+	}
+	printf("\"util\": %.2f}",
 		 shi->used ? xds->util / 10.0 / (double) shi->used
 			   : xds->util / 10.0);	/* shi->used should never be zero here */
 }
@@ -1108,7 +1203,7 @@ void write_ext_stat(unsigned long long itv, int fctr,
 	char *devname = NULL;
 	struct stats_disk sdc, sdp;
 	struct ext_disk_stats xds;
-	double r_await, w_await;
+	struct ext_io_stats xios;
 
 	/*
 	 * Counters overflows are possible, but don't need to be handled in
@@ -1137,12 +1232,36 @@ void write_ext_stat(unsigned long long itv, int fctr,
 
 	compute_ext_disk_stats(&sdc, &sdp, itv, &xds);
 
-	r_await = (ioi->rd_ios - ioj->rd_ios) ?
-		  (ioi->rd_ticks - ioj->rd_ticks) /
-		  ((double) (ioi->rd_ios - ioj->rd_ios)) : 0.0;
-	w_await = (ioi->wr_ios - ioj->wr_ios) ?
-		  (ioi->wr_ticks - ioj->wr_ticks) /
-		  ((double) (ioi->wr_ios - ioj->wr_ios)) : 0.0;
+	/* r_await  w_await */
+	xios.r_await = (ioi->rd_ios - ioj->rd_ios) ?
+		       (ioi->rd_ticks - ioj->rd_ticks) /
+		       ((double) (ioi->rd_ios - ioj->rd_ios)) : 0.0;
+	xios.w_await = (ioi->wr_ios - ioj->wr_ios) ?
+		       (ioi->wr_ticks - ioj->wr_ticks) /
+		       ((double) (ioi->wr_ios - ioj->wr_ios)) : 0.0;
+
+	/* rkB/s  wkB/s */
+	xios.rsectors = S_VALUE(ioj->rd_sectors, ioi->rd_sectors, itv);
+	xios.wsectors = S_VALUE(ioj->wr_sectors, ioi->wr_sectors, itv);
+	xios.sectors  = xios.rsectors + xios.wsectors;
+
+	/* %rrqm  %wrqm */
+	xios.rrqm_pc = (ioi->rd_merges - ioj->rd_merges) + (ioi->rd_ios - ioj->rd_ios) ?
+		       (double) ((ioi->rd_merges - ioj->rd_merges)) /
+		       ((ioi->rd_merges - ioj->rd_merges) + (ioi->rd_ios - ioj->rd_ios)) * 100 :
+		       0.0;
+	xios.wrqm_pc = (ioi->wr_merges - ioj->wr_merges) + (ioi->wr_ios - ioj->wr_ios) ?
+		       (double) ((ioi->wr_merges - ioj->wr_merges)) /
+		       ((ioi->wr_merges - ioj->wr_merges) + (ioi->wr_ios - ioj->wr_ios)) * 100 :
+		       0.0;
+
+	/* rareq-sz  wareq-sz (still in sectors, not kB) */
+	xios.rarqsz = (ioi->rd_ios - ioj->rd_ios) ?
+		      (ioi->rd_sectors - ioj->rd_sectors) / ((double) (ioi->rd_ios - ioj->rd_ios)) :
+		      0.0;
+	xios.warqsz = (ioi->wr_ios - ioj->wr_ios) ?
+		      (ioi->wr_sectors - ioj->wr_sectors) / ((double) (ioi->wr_ios - ioj->wr_ios)) :
+		      0.0;
 
 	/* Get device name */
 	if (DISPLAY_PERSIST_NAME_I(flags)) {
@@ -1153,12 +1272,10 @@ void write_ext_stat(unsigned long long itv, int fctr,
 	}
 
 	if (DISPLAY_JSON_OUTPUT(flags)) {
-		write_json_ext_stat(tab, itv, fctr, shi, ioi, ioj, devname, &xds,
-				    r_await, w_await);
+		write_json_ext_stat(tab, itv, fctr, shi, ioi, ioj, devname, &xds, &xios);
 	}
 	else {
-		write_plain_ext_stat(itv, fctr, shi, ioi, ioj, devname, &xds,
-				     r_await, w_await);
+		write_plain_ext_stat(itv, fctr, shi, ioi, ioj, devname, &xds, &xios);
 	}
 }
 
@@ -1191,7 +1308,7 @@ void write_plain_basic_stat(unsigned long long itv, int fctr,
 	else {
 		cprintf_in(IS_STR, "%-13s", devname, 0);
 	}
-	cprintf_f(-1, 1, 8, 2,
+	cprintf_f(NO_UNIT, 1, 8, 2,
 		  S_VALUE(ioj->rd_ios + ioj->wr_ios, ioi->rd_ios + ioi->wr_ios, itv));
 	rsectors = S_VALUE(ioj->rd_sectors, ioi->rd_sectors, itv);
 	wsectors = S_VALUE(ioj->wr_sectors, ioi->wr_sectors, itv);
@@ -1199,9 +1316,9 @@ void write_plain_basic_stat(unsigned long long itv, int fctr,
 		rsectors /= fctr;
 		wsectors /= fctr;
 	}
-	cprintf_f(DISPLAY_UNIT(flags) ? 0 : -1, 2, 12, 2,
+	cprintf_f(DISPLAY_UNIT(flags) ? UNIT_SECTOR : NO_UNIT, 2, 12, 2,
 		  rsectors, wsectors);
-	cprintf_u64(DISPLAY_UNIT(flags) ? 0 : -1, 2, 10,
+	cprintf_u64(DISPLAY_UNIT(flags) ? UNIT_SECTOR : NO_UNIT, 2, 10,
 		    DISPLAY_UNIT(flags) ? (unsigned long long) rd_sec
 					: (unsigned long long) rd_sec / fctr,
 		    DISPLAY_UNIT(flags) ? (unsigned long long) wr_sec
@@ -1230,16 +1347,29 @@ void write_json_basic_stat(int tab, unsigned long long itv, int fctr,
 			   char *devname, unsigned long long rd_sec,
 			   unsigned long long wr_sec)
 {
+	char line[256];
+
 	xprintf0(tab,
-		 "{\"disk_device\": \"%s\", \"tps\": %.2f, "
-		 "\"kB_read_per_sec\": %.2f, \"kB_wrtn_per_sec\": %.2f, "
-		 "\"kB_read\": %llu, \"kB_wrtn\": %llu}",
+		 "{\"disk_device\": \"%s\", \"tps\": %.2f, ",
 		 devname,
-		 S_VALUE(ioj->rd_ios + ioj->wr_ios, ioi->rd_ios + ioi->wr_ios, itv),
-		 S_VALUE(ioj->rd_sectors, ioi->rd_sectors, itv) / fctr,
-		 S_VALUE(ioj->wr_sectors, ioi->wr_sectors, itv) / fctr,
-		 (unsigned long long) rd_sec / fctr,
-		 (unsigned long long) wr_sec / fctr);
+		 S_VALUE(ioj->rd_ios + ioj->wr_ios, ioi->rd_ios + ioi->wr_ios, itv));
+	if (DISPLAY_KILOBYTES(flags)) {
+		sprintf(line, "\"kB_read/s\": %%.2f, \"kB_wrtn/s\": %%.2f, "
+			"\"kB_read\": %%llu, \"kB_wrtn\": %%llu}");
+	}
+	else if (DISPLAY_MEGABYTES(flags)) {
+		sprintf(line, "\"MB_read/s\": %%.2f, \"MB_wrtn/s\": %%.2f, "
+			"\"MB_read\": %%llu, \"MB_wrtn\": %%llu}");
+	}
+	else {
+		sprintf(line, "\"Blk_read/s\": %%.2f, \"Blk_wrtn/s\": %%.2f, "
+			"\"Blk_read\": %%llu, \"Blk_wrtn\": %%llu}");
+	}
+	printf(line,
+	       S_VALUE(ioj->rd_sectors, ioi->rd_sectors, itv) / fctr,
+	       S_VALUE(ioj->wr_sectors, ioi->wr_sectors, itv) / fctr,
+	       (unsigned long long) rd_sec / fctr,
+	       (unsigned long long) wr_sec / fctr);
 }
 
 /*
@@ -1768,6 +1898,11 @@ int main(int argc, char **argv)
 					flags |= I_D_PARTITIONS + I_D_PART_ALL;
 					break;
 
+				case 's':
+					/* Display short output */
+					flags |= I_D_SHORT_OUTPUT;
+					break;
+
 				case 't':
 					/* Display timestamp */
 					flags |= I_D_TIMESTAMP;
