@@ -1,6 +1,6 @@
 /*
  * pr_stats.c: Functions used by sar to display statistics
- * (C) 1999-2016 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2017 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -179,7 +179,7 @@ __print_funct_t print_cpu_stats(struct activity *a, int prev, int curr,
 				*scc = *scp;
 
 				/* %user, %nice, %system, %iowait, %steal, ..., %idle */
-				cprintf_pc(6, 9, 2,
+				cprintf_pc(DISPLAY_UNIT(flags), 6, 9, 2,
 					   0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
 
 				if (DISPLAY_CPU_ALL(a->opt_flags)) {
@@ -187,7 +187,7 @@ __print_funct_t print_cpu_stats(struct activity *a, int prev, int curr,
 					 * Four additional fields to display:
 					 * %irq, %soft, %guest, %gnice.
 					 */
-					cprintf_pc(4, 9, 2,
+					cprintf_pc(DISPLAY_UNIT(flags), 4, 9, 2,
 						   0.0, 0.0, 0.0, 0.0);
 				}
 				printf("\n");
@@ -203,11 +203,11 @@ __print_funct_t print_cpu_stats(struct activity *a, int prev, int curr,
 				 * but the sum of values is not zero.
 				 * %user, %nice, %system, %iowait, %steal, ..., %idle
 				 */
-				cprintf_pc(5, 9, 2,
+				cprintf_pc(DISPLAY_UNIT(flags), 5, 9, 2,
 					   0.0, 0.0, 0.0, 0.0, 0.0);
 
 				if (DISPLAY_CPU_DEF(a->opt_flags)) {
-					cprintf_pc(1, 9, 2, 100.0);
+					cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2, 100.0);
 					printf("\n");
 				}
 				/*
@@ -215,7 +215,7 @@ __print_funct_t print_cpu_stats(struct activity *a, int prev, int curr,
 				 * %irq, %soft, %guest, %gnice.
 				 */
 				else if (DISPLAY_CPU_ALL(a->opt_flags)) {
-					cprintf_pc(4, 9, 2,
+					cprintf_pc(DISPLAY_UNIT(flags), 4, 9, 2,
 						   0.0, 0.0, 0.0, 100.0);
 					printf("\n");
 				}
@@ -224,7 +224,7 @@ __print_funct_t print_cpu_stats(struct activity *a, int prev, int curr,
 		}
 
 		if (DISPLAY_CPU_DEF(a->opt_flags)) {
-			cprintf_pc(6, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 6, 9, 2,
 				   ll_sp_value(scp->cpu_user, scc->cpu_user, g_itv),
 				   ll_sp_value(scp->cpu_nice, scc->cpu_nice, g_itv),
 				   ll_sp_value(scp->cpu_sys + scp->cpu_hardirq + scp->cpu_softirq,
@@ -238,7 +238,7 @@ __print_funct_t print_cpu_stats(struct activity *a, int prev, int curr,
 			printf("\n");
 		}
 		else if (DISPLAY_CPU_ALL(a->opt_flags)) {
-			cprintf_pc(10, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 10, 9, 2,
 				   (scc->cpu_user - scc->cpu_guest) < (scp->cpu_user - scp->cpu_guest) ?
 				   0.0 :
 				   ll_sp_value(scp->cpu_user - scp->cpu_guest,
@@ -285,7 +285,7 @@ __print_funct_t print_pcsw_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 2, 9, 2,
+	cprintf_f(NO_UNIT, 2, 9, 2,
 		  S_VALUE(spp->processes,      spc->processes,      itv),
 		  S_VALUE(spp->context_switch, spc->context_switch, itv));
 	printf("\n");
@@ -338,7 +338,7 @@ __print_funct_t print_irq_stats(struct activity *a, int prev, int curr,
 				cprintf_in(IS_INT, " %9d", "", i -1);
 			}
 
-			cprintf_f(-1, 1, 9, 2, S_VALUE(sip->irq_nr, sic->irq_nr, itv));
+			cprintf_f(NO_UNIT, 1, 9, 2, S_VALUE(sip->irq_nr, sic->irq_nr, itv));
 			printf("\n");
 		}
 	}
@@ -367,7 +367,7 @@ __print_funct_t print_swap_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 2, 9, 2,
+	cprintf_f(NO_UNIT, 2, 9, 2,
 		  S_VALUE(ssp->pswpin,  ssc->pswpin,  itv),
 		  S_VALUE(ssp->pswpout, ssc->pswpout, itv));
 	printf("\n");
@@ -396,7 +396,7 @@ __print_funct_t print_paging_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 8, 9, 2,
+	cprintf_f(NO_UNIT, 8, 9, 2,
 		  S_VALUE(spp->pgpgin,        spc->pgpgin,        itv),
 		  S_VALUE(spp->pgpgout,       spc->pgpgout,       itv),
 		  S_VALUE(spp->pgfault,       spc->pgfault,       itv),
@@ -405,7 +405,7 @@ __print_funct_t print_paging_stats(struct activity *a, int prev, int curr,
 		  S_VALUE(spp->pgscan_kswapd, spc->pgscan_kswapd, itv),
 		  S_VALUE(spp->pgscan_direct, spc->pgscan_direct, itv),
 		  S_VALUE(spp->pgsteal,       spc->pgsteal,       itv));
-	cprintf_pc(1, 9, 2,
+	cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 		   (spc->pgscan_kswapd + spc->pgscan_direct -
 		   spp->pgscan_kswapd - spp->pgscan_direct) ?
 		   SP_VALUE(spp->pgsteal, spc->pgsteal,
@@ -444,7 +444,7 @@ __print_funct_t print_io_stats(struct activity *a, int prev, int curr,
 	 * We display 0.0 in this case though we should rather tell
 	 * the user that the value cannot be calculated here.
 	 */
-	cprintf_f(-1, 5, 9, 2,
+	cprintf_f(NO_UNIT, 5, 9, 2,
 		  sic->dk_drive < sip->dk_drive ? 0.0 :
 		  S_VALUE(sip->dk_drive, sic->dk_drive, itv),
 		  sic->dk_drive_rio < sip->dk_drive_rio ? 0.0 :
@@ -494,11 +494,11 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 		avg_frskb = 0,
 		avg_tlskb = 0,
 		avg_caskb = 0;
-	int unit = -1;
+	int unit = NO_UNIT;
 
 	if (DISPLAY_UNIT(flags)) {
 		/* Default values unit is kB */
-		unit = 2;
+		unit = UNIT_KILOBYTE;
 	}
 
 	if (DISPLAY_MEMORY(a->opt_flags)) {
@@ -513,7 +513,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 				    (unsigned long long) smc->frmkb,
 				    (unsigned long long) smc->availablekb,
 				    (unsigned long long) (smc->tlmkb - smc->frmkb));
-			cprintf_pc(1, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   smc->tlmkb ?
 				   SP_VALUE(smc->frmkb, smc->tlmkb, smc->tlmkb)
 				   : 0.0);
@@ -521,7 +521,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 				    (unsigned long long) smc->bufkb,
 				    (unsigned long long) smc->camkb,
 				    (unsigned long long) smc->comkb);
-			cprintf_pc(1, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   (smc->tlmkb + smc->tlskb) ?
 				   SP_VALUE(0, smc->comkb, smc->tlmkb + smc->tlskb)
 				   : 0.0);
@@ -568,7 +568,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 				  (double) avg_frmkb / avg_count,
 				  (double) avg_availablekb / avg_count,
 				  (double) smc->tlmkb - ((double) avg_frmkb / avg_count));
-			cprintf_pc(1, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   smc->tlmkb ?
 				   SP_VALUE((double) (avg_frmkb / avg_count), smc->tlmkb, smc->tlmkb)
 				   : 0.0);
@@ -576,7 +576,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 				  (double) avg_bufkb / avg_count,
 				  (double) avg_camkb / avg_count,
 				  (double) avg_comkb / avg_count);
-			cprintf_pc(1, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   (smc->tlmkb + smc->tlskb) ?
 				   SP_VALUE(0.0, (double) (avg_comkb / avg_count), smc->tlmkb + smc->tlskb)
 				   : 0.0);
@@ -615,13 +615,13 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 			cprintf_u64(unit, 2, 9,
 				    (unsigned long long) smc->frskb,
 				    (unsigned long long) (smc->tlskb - smc->frskb));
-			cprintf_pc(1, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   smc->tlskb ?
 				   SP_VALUE(smc->frskb, smc->tlskb, smc->tlskb)
 				   : 0.0);
 			cprintf_u64(unit, 1, 9,
 				    (unsigned long long) smc->caskb);
-			cprintf_pc(1, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   (smc->tlskb - smc->frskb) ?
 				   SP_VALUE(0, smc->caskb, smc->tlskb - smc->frskb)
 				   : 0.0);
@@ -643,7 +643,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 				  (double) avg_frskb / avg_count,
 				  ((double) avg_tlskb / avg_count) -
 				  ((double) avg_frskb / avg_count));
-			cprintf_pc(1, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   avg_tlskb ?
 				   SP_VALUE((double) avg_frskb / avg_count,
 					    (double) avg_tlskb / avg_count,
@@ -651,7 +651,7 @@ void stub_print_memory_stats(struct activity *a, int prev, int curr,
 				   : 0.0);
 			cprintf_f(unit, 1, 9, 0,
 				  (double) avg_caskb / avg_count);
-			cprintf_pc(1, 9, 2,
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   (avg_tlskb != avg_frskb) ?
 				   SP_VALUE(0.0, (double) avg_caskb / avg_count,
 					    ((double) avg_tlskb / avg_count) -
@@ -728,7 +728,7 @@ void stub_print_ktables_stats(struct activity *a, int curr, int dispavg)
 	if (!dispavg) {
 		/* Display instantaneous values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_u64(-1, 4, 9,
+		cprintf_u64(NO_UNIT, 4, 9,
 			    (unsigned long long) skc->dentry_stat,
 			    (unsigned long long) skc->file_used,
 			    (unsigned long long) skc->inode_used,
@@ -747,7 +747,7 @@ void stub_print_ktables_stats(struct activity *a, int curr, int dispavg)
 	else {
 		/* Display average values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(-1, 4, 9, 0,
+		cprintf_f(NO_UNIT, 4, 9, 0,
 			  (double) avg_dentry_stat / avg_count,
 			  (double) avg_file_used   / avg_count,
 			  (double) avg_inode_used  / avg_count,
@@ -823,14 +823,14 @@ void stub_print_queue_stats(struct activity *a, int curr, int dispavg)
 	if (!dispavg) {
 		/* Display instantaneous values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_u64(-1, 2, 9,
+		cprintf_u64(NO_UNIT, 2, 9,
 			    (unsigned long long) sqc->nr_running,
 			    (unsigned long long) sqc->nr_threads);
-		cprintf_f(-1, 3, 9, 2,
+		cprintf_f(NO_UNIT, 3, 9, 2,
 			  (double) sqc->load_avg_1  / 100,
 			  (double) sqc->load_avg_5  / 100,
 			  (double) sqc->load_avg_15 / 100);
-		cprintf_u64(-1, 1, 9,
+		cprintf_u64(NO_UNIT, 1, 9,
 			    (unsigned long long) sqc->procs_blocked);
 		printf("\n");
 
@@ -845,14 +845,14 @@ void stub_print_queue_stats(struct activity *a, int curr, int dispavg)
 	else {
 		/* Display average values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(-1, 2, 9, 0,
+		cprintf_f(NO_UNIT, 2, 9, 0,
 			  (double) avg_nr_running / avg_count,
 			  (double) avg_nr_threads / avg_count);
-		cprintf_f(-1, 3, 9, 2,
+		cprintf_f(NO_UNIT, 3, 9, 2,
 			  (double) avg_load_avg_1  / (avg_count * 100),
 			  (double) avg_load_avg_5  / (avg_count * 100),
 			  (double) avg_load_avg_15 / (avg_count * 100));
-		cprintf_f(-1, 1, 9, 0,
+		cprintf_f(NO_UNIT, 1, 9, 0,
 			  (double) avg_procs_blocked / avg_count);
 		printf("\n");
 
@@ -930,7 +930,7 @@ __print_funct_t print_serial_stats(struct activity *a, int prev, int curr,
 		cprintf_in(IS_INT, "       %3d", "", ssc->line - 1);
 
 		if ((ssc->line == ssp->line) || WANT_SINCE_BOOT(flags)) {
-			cprintf_f(-1, 6, 9, 2,
+			cprintf_f(NO_UNIT, 6, 9, 2,
 				  S_VALUE(ssp->rx,      ssc->rx,      itv),
 				  S_VALUE(ssp->tx,      ssc->tx,      itv),
 				  S_VALUE(ssp->frame,   ssc->frame,   itv),
@@ -964,13 +964,13 @@ __print_funct_t print_disk_stats(struct activity *a, int prev, int curr,
 	struct stats_disk *sdc,	*sdp, sdpzero;
 	struct ext_disk_stats xds;
 	char *dev_name, *persist_dev_name;
-	int unit = -1;
+	int unit = NO_UNIT;
 
 	memset(&sdpzero, 0, STATS_DISK_SIZE);
 
 	if (DISPLAY_UNIT(flags)) {
-		/* Default values unit is sectors */
-		unit = 0;
+		/* Default values unit is kB */
+		unit = UNIT_KILOBYTE;
 	}
 
 	if (dis) {
@@ -1020,18 +1020,19 @@ __print_funct_t print_disk_stats(struct activity *a, int prev, int curr,
 		printf("%-11s", timestamp[curr]);
 
 		cprintf_in(IS_STR, " %9s", dev_name, 0);
-		cprintf_f(-1, 1, 9, 2,
+		cprintf_f(NO_UNIT, 1, 9, 2,
 			  S_VALUE(sdp->nr_ios, sdc->nr_ios,  itv));
 		cprintf_f(unit, 2, 9, 2,
-			  S_VALUE(sdp->rd_sect, sdc->rd_sect, itv),
-			  S_VALUE(sdp->wr_sect, sdc->wr_sect, itv));
-		cprintf_f(-1, 4, 9, 2,
-			  /* See iostat for explanations */
-			  xds.arqsz,
+			  S_VALUE(sdp->rd_sect, sdc->rd_sect, itv) / 2,
+			  S_VALUE(sdp->wr_sect, sdc->wr_sect, itv) / 2);
+		/* See iostat for explanations */
+		cprintf_f(unit, 1, 9, 2,
+			  xds.arqsz / 2);
+		cprintf_f(NO_UNIT, 3, 9, 2,
 			  S_VALUE(sdp->rq_ticks, sdc->rq_ticks, itv) / 1000.0,
 			  xds.await,
 			  xds.svctm);
-		cprintf_pc(1, 9, 2,
+		cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 			   xds.util / 10.0);
 		printf("\n");
 	}
@@ -1054,13 +1055,13 @@ __print_funct_t print_net_dev_stats(struct activity *a, int prev, int curr,
 	int i, j;
 	struct stats_net_dev *sndc, *sndp, sndzero;
 	double rxkb, txkb, ifutil;
-	int unit = -1;
+	int unit = NO_UNIT;
 
 	memset(&sndzero, 0, STATS_NET_DEV_SIZE);
 
 	if (DISPLAY_UNIT(flags)) {
 		/* Default values unit is bytes */
-		unit = 1;
+		unit = UNIT_BYTE;
 	}
 
 	if (dis) {
@@ -1089,18 +1090,18 @@ __print_funct_t print_net_dev_stats(struct activity *a, int prev, int curr,
 		rxkb = S_VALUE(sndp->rx_bytes, sndc->rx_bytes, itv);
 		txkb = S_VALUE(sndp->tx_bytes, sndc->tx_bytes, itv);
 
-		cprintf_f(-1, 2, 9, 2,
+		cprintf_f(NO_UNIT, 2, 9, 2,
 			  S_VALUE(sndp->rx_packets, sndc->rx_packets, itv),
 			  S_VALUE(sndp->tx_packets, sndc->tx_packets, itv));
 		cprintf_f(unit, 2, 9, 2,
 			  unit < 0 ? rxkb / 1024 : rxkb,
 			  unit < 0 ? txkb / 1024 : txkb);
-		cprintf_f(-1, 3, 9, 2,
+		cprintf_f(NO_UNIT, 3, 9, 2,
 			  S_VALUE(sndp->rx_compressed, sndc->rx_compressed, itv),
 			  S_VALUE(sndp->tx_compressed, sndc->tx_compressed, itv),
 			  S_VALUE(sndp->multicast,     sndc->multicast,     itv));
 		ifutil = compute_ifutil(sndc, rxkb, txkb);
-		cprintf_pc(1, 9, 2, ifutil);
+		cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2, ifutil);
 		printf("\n");
 	}
 }
@@ -1147,7 +1148,7 @@ __print_funct_t print_net_edev_stats(struct activity *a, int prev, int curr,
 		printf("%-11s", timestamp[curr]);
 		cprintf_in(IS_STR, " %9s", snedc->interface, 0);
 
-		cprintf_f(-1, 9, 9, 2,
+		cprintf_f(NO_UNIT, 9, 9, 2,
 			  S_VALUE(snedp->rx_errors,         snedc->rx_errors,         itv),
 			  S_VALUE(snedp->tx_errors,         snedc->tx_errors,         itv),
 			  S_VALUE(snedp->collisions,        snedc->collisions,        itv),
@@ -1184,7 +1185,7 @@ __print_funct_t print_net_nfs_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 6, 9, 2,
+	cprintf_f(NO_UNIT, 6, 9, 2,
 		  S_VALUE(snnp->nfs_rpccnt,     snnc->nfs_rpccnt,     itv),
 		  S_VALUE(snnp->nfs_rpcretrans, snnc->nfs_rpcretrans, itv),
 		  S_VALUE(snnp->nfs_readcnt,    snnc->nfs_readcnt,    itv),
@@ -1217,7 +1218,7 @@ __print_funct_t print_net_nfsd_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 11, 9, 2,
+	cprintf_f(NO_UNIT, 11, 9, 2,
 		  S_VALUE(snndp->nfsd_rpccnt,    snndc->nfsd_rpccnt,    itv),
 		  S_VALUE(snndp->nfsd_rpcbad,    snndc->nfsd_rpcbad,    itv),
 		  S_VALUE(snndp->nfsd_netcnt,    snndc->nfsd_netcnt,    itv),
@@ -1262,7 +1263,7 @@ void stub_print_net_sock_stats(struct activity *a, int curr, int dispavg)
 	if (!dispavg) {
 		/* Display instantaneous values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_u64(-1, 6, 9,
+		cprintf_u64(NO_UNIT, 6, 9,
 			    (unsigned long long) snsc->sock_inuse,
 			    (unsigned long long) snsc->tcp_inuse,
 			    (unsigned long long) snsc->udp_inuse,
@@ -1282,7 +1283,7 @@ void stub_print_net_sock_stats(struct activity *a, int curr, int dispavg)
 	else {
 		/* Display average values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(-1, 6, 9, 0,
+		cprintf_f(NO_UNIT, 6, 9, 0,
 			  (double) avg_sock_inuse / avg_count,
 			  (double) avg_tcp_inuse  / avg_count,
 			  (double) avg_udp_inuse  / avg_count,
@@ -1354,7 +1355,7 @@ __print_funct_t print_net_ip_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 8, 9, 2,
+	cprintf_f(NO_UNIT, 8, 9, 2,
 		  S_VALUE(snip->InReceives,    snic->InReceives,    itv),
 		  S_VALUE(snip->ForwDatagrams, snic->ForwDatagrams, itv),
 		  S_VALUE(snip->InDelivers,    snic->InDelivers,    itv),
@@ -1389,7 +1390,7 @@ __print_funct_t print_net_eip_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 8, 9, 2,
+	cprintf_f(NO_UNIT, 8, 9, 2,
 		  S_VALUE(sneip->InHdrErrors,     sneic->InHdrErrors,     itv),
 		  S_VALUE(sneip->InAddrErrors,    sneic->InAddrErrors,    itv),
 		  S_VALUE(sneip->InUnknownProtos, sneic->InUnknownProtos, itv),
@@ -1424,7 +1425,7 @@ __print_funct_t print_net_icmp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 14, 9, 2,
+	cprintf_f(NO_UNIT, 14, 9, 2,
 		  S_VALUE(snip->InMsgs,           snic->InMsgs,           itv),
 		  S_VALUE(snip->OutMsgs,          snic->OutMsgs,          itv),
 		  S_VALUE(snip->InEchos,          snic->InEchos,          itv),
@@ -1465,7 +1466,7 @@ __print_funct_t print_net_eicmp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 12, 9, 2,
+	cprintf_f(NO_UNIT, 12, 9, 2,
 		  S_VALUE(sneip->InErrors,        sneic->InErrors,        itv),
 		  S_VALUE(sneip->OutErrors,       sneic->OutErrors,       itv),
 		  S_VALUE(sneip->InDestUnreachs,  sneic->InDestUnreachs,  itv),
@@ -1504,7 +1505,7 @@ __print_funct_t print_net_tcp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 4, 9, 2,
+	cprintf_f(NO_UNIT, 4, 9, 2,
 		  S_VALUE(sntp->ActiveOpens,  sntc->ActiveOpens,  itv),
 		  S_VALUE(sntp->PassiveOpens, sntc->PassiveOpens, itv),
 		  S_VALUE(sntp->InSegs,       sntc->InSegs,       itv),
@@ -1535,7 +1536,7 @@ __print_funct_t print_net_etcp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 5, 9, 2,
+	cprintf_f(NO_UNIT, 5, 9, 2,
 		  S_VALUE(snetp->AttemptFails, snetc->AttemptFails, itv),
 		  S_VALUE(snetp->EstabResets,  snetc->EstabResets,  itv),
 		  S_VALUE(snetp->RetransSegs,  snetc->RetransSegs,  itv),
@@ -1567,7 +1568,7 @@ __print_funct_t print_net_udp_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 4, 9, 2,
+	cprintf_f(NO_UNIT, 4, 9, 2,
 		  S_VALUE(snup->InDatagrams,  snuc->InDatagrams,  itv),
 		  S_VALUE(snup->OutDatagrams, snuc->OutDatagrams, itv),
 		  S_VALUE(snup->NoPorts,      snuc->NoPorts,      itv),
@@ -1603,7 +1604,7 @@ void stub_print_net_sock6_stats(struct activity *a, int curr, int dispavg)
 	if (!dispavg) {
 		/* Display instantaneous values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_u64(-1, 4, 9,
+		cprintf_u64(NO_UNIT, 4, 9,
 			    (unsigned long long) snsc->tcp6_inuse,
 			    (unsigned long long) snsc->udp6_inuse,
 			    (unsigned long long) snsc->raw6_inuse,
@@ -1619,7 +1620,7 @@ void stub_print_net_sock6_stats(struct activity *a, int curr, int dispavg)
 	else {
 		/* Display average values */
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(-1, 4, 9, 0,
+		cprintf_f(NO_UNIT, 4, 9, 0,
 			  (double) avg_tcp6_inuse  / avg_count,
 			  (double) avg_udp6_inuse  / avg_count,
 			  (double) avg_raw6_inuse  / avg_count,
@@ -1688,7 +1689,7 @@ __print_funct_t print_net_ip6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 10, 9, 2,
+	cprintf_f(NO_UNIT, 10, 9, 2,
 		  S_VALUE(snip->InReceives6,       snic->InReceives6,       itv),
 		  S_VALUE(snip->OutForwDatagrams6, snic->OutForwDatagrams6, itv),
 		  S_VALUE(snip->InDelivers6,       snic->InDelivers6,       itv),
@@ -1725,7 +1726,7 @@ __print_funct_t print_net_eip6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 11, 9, 2,
+	cprintf_f(NO_UNIT, 11, 9, 2,
 		  S_VALUE(sneip->InHdrErrors6,     sneic->InHdrErrors6,     itv),
 		  S_VALUE(sneip->InAddrErrors6,    sneic->InAddrErrors6,    itv),
 		  S_VALUE(sneip->InUnknownProtos6, sneic->InUnknownProtos6, itv),
@@ -1763,7 +1764,7 @@ __print_funct_t print_net_icmp6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 17, 9, 2,
+	cprintf_f(NO_UNIT, 17, 9, 2,
 		  S_VALUE(snip->InMsgs6,                    snic->InMsgs6,                    itv),
 		  S_VALUE(snip->OutMsgs6,                   snic->OutMsgs6,                   itv),
 		  S_VALUE(snip->InEchos6,                   snic->InEchos6,                   itv),
@@ -1807,7 +1808,7 @@ __print_funct_t print_net_eicmp6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 11, 9, 2,
+	cprintf_f(NO_UNIT, 11, 9, 2,
 		  S_VALUE(sneip->InErrors6,        sneic->InErrors6,        itv),
 		  S_VALUE(sneip->InDestUnreachs6,  sneic->InDestUnreachs6,  itv),
 		  S_VALUE(sneip->OutDestUnreachs6, sneic->OutDestUnreachs6, itv),
@@ -1845,7 +1846,7 @@ __print_funct_t print_net_udp6_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
-	cprintf_f(-1, 4, 9, 2,
+	cprintf_f(NO_UNIT, 4, 9, 2,
 		  S_VALUE(snup->InDatagrams6,  snuc->InDatagrams6,  itv),
 		  S_VALUE(snup->OutDatagrams6, snuc->OutDatagrams6, itv),
 		  S_VALUE(snup->NoPorts6,      snuc->NoPorts6,      itv),
@@ -1919,7 +1920,7 @@ void stub_print_pwr_cpufreq_stats(struct activity *a, int curr, int dispavg)
 
 			if (!dispavg) {
 				/* Display instantaneous values */
-				cprintf_f(-1, 1, 9, 2,
+				cprintf_f(NO_UNIT, 1, 9, 2,
 					  ((double) spc->cpufreq) / 100);
 				printf("\n");
 				/*
@@ -1930,7 +1931,7 @@ void stub_print_pwr_cpufreq_stats(struct activity *a, int curr, int dispavg)
 			}
 			else {
 				/* Display average values */
-				cprintf_f(-1, 1, 9, 2,
+				cprintf_f(NO_UNIT, 1, 9, 2,
 					  (double) avg_cpufreq[i] / (100 * avg_count));
 				printf("\n");
 			}
@@ -2026,13 +2027,13 @@ void stub_print_pwr_fan_stats(struct activity *a, int curr, int dispavg)
 
 		if (dispavg) {
 			/* Display average values */
-			cprintf_f(-1, 2, 9, 2,
+			cprintf_f(NO_UNIT, 2, 9, 2,
 				  (double) avg_fan[i] / avg_count,
 				  (double) (avg_fan[i] - avg_fan_min[i]) / avg_count);
 		}
 		else {
 			/* Display instantaneous values */
-			cprintf_f(-1, 2, 9, 2,
+			cprintf_f(NO_UNIT, 2, 9, 2,
 				  spc->rpm,
 				  spc->rpm - spc->rpm_min);
 			avg_fan[i]     += spc->rpm;
@@ -2141,16 +2142,16 @@ void stub_print_pwr_temp_stats(struct activity *a, int curr, int dispavg)
 
 		if (dispavg) {
 			/* Display average values */
-			cprintf_f(-1, 1, 9, 2, (double) avg_temp[i] / avg_count);
-			cprintf_pc(1, 9, 2,
+			cprintf_f(NO_UNIT, 1, 9, 2, (double) avg_temp[i] / avg_count);
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   (avg_temp_max[i] - avg_temp_min[i]) ?
 				   ((double) (avg_temp[i] / avg_count) - avg_temp_min[i]) / (avg_temp_max[i] - avg_temp_min[i]) * 100
 				   : 0.0);
 		}
 		else {
 			/* Display instantaneous values */
-			cprintf_f(-1, 1, 9, 2, spc->temp);
-			cprintf_pc(1, 9, 2,
+			cprintf_f(NO_UNIT, 1, 9, 2, spc->temp);
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   (spc->temp_max - spc->temp_min) ?
 				   (spc->temp - spc->temp_min) / (spc->temp_max - spc->temp_min) * 100
 				   : 0.0);
@@ -2266,16 +2267,16 @@ void stub_print_pwr_in_stats(struct activity *a, int curr, int dispavg)
 
 		if (dispavg) {
 			/* Display average values */
-			cprintf_f(-1, 1, 9, 2, (double) avg_in[i] / avg_count);
-			cprintf_pc(1, 9, 2,
+			cprintf_f(NO_UNIT, 1, 9, 2, (double) avg_in[i] / avg_count);
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   (avg_in_max[i] - avg_in_min[i]) ?
 				   ((double) (avg_in[i] / avg_count) - avg_in_min[i]) / (avg_in_max[i] - avg_in_min[i]) * 100
 				   : 0.0);
 		}
 		else {
 			/* Display instantaneous values */
-			cprintf_f(-1, 1, 9, 2, spc->in);
-			cprintf_pc(1, 9, 2,
+			cprintf_f(NO_UNIT, 1, 9, 2, spc->in);
+			cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 				   (spc->in_max - spc->in_min) ?
 				   (spc->in - spc->in_min) / (spc->in_max - spc->in_min) * 100
 				   : 0.0);
@@ -2356,11 +2357,11 @@ void stub_print_huge_stats(struct activity *a, int curr, int dispavg)
 	static unsigned long long
 		avg_frhkb = 0,
 		avg_tlhkb = 0;
-	int unit = -1;
+	int unit = NO_UNIT;
 
 	if (DISPLAY_UNIT(flags)) {
 		/* Default values unit is kB */
-		unit = 2;
+		unit = UNIT_KILOBYTE;
 	}
 
 	if (dis) {
@@ -2373,7 +2374,7 @@ void stub_print_huge_stats(struct activity *a, int curr, int dispavg)
 		cprintf_u64(unit, 2, 9,
 			    (unsigned long long) smc->frhkb,
 			    (unsigned long long) (smc->tlhkb - smc->frhkb));
-		cprintf_pc(1, 9, 2,
+		cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 			   smc->tlhkb ?
 			   SP_VALUE(smc->frhkb, smc->tlhkb, smc->tlhkb) : 0.0);
 		printf("\n");
@@ -2389,7 +2390,7 @@ void stub_print_huge_stats(struct activity *a, int curr, int dispavg)
 			  (double) avg_frhkb / avg_count,
 			  ((double) avg_tlhkb / avg_count) -
 			  ((double) avg_frhkb / avg_count));
-		cprintf_pc(1, 9, 2,
+		cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 			   avg_tlhkb ?
 			   SP_VALUE((double) avg_frhkb / avg_count,
 				    (double) avg_tlhkb / avg_count,
@@ -2507,7 +2508,7 @@ void print_pwr_wghfreq_stats(struct activity *a, int prev, int curr,
 			}
 
 			/* Display weighted frequency for current CPU */
-			cprintf_f(-1, 1, 9, 2,
+			cprintf_f(NO_UNIT, 1, 9, 2,
 				  tis ? ((double) tisfreq) / tis : 0.0);
 			printf("\n");
 		}
@@ -2550,7 +2551,7 @@ void stub_print_pwr_usb_stats(struct activity *a, int curr, int dispavg)
 		cprintf_x(2, 9,
 			  suc->vendor_id,
 			  suc->product_id);
-		cprintf_u64(-1, 1, 9,
+		cprintf_u64(NO_UNIT, 1, 9,
 			    /* bMaxPower is expressed in 2 mA units */
 			    (unsigned long long) (suc->bmaxpower << 1));
 
@@ -2644,11 +2645,11 @@ __print_funct_t stub_print_filesystem_stats(struct activity *a, int curr, int di
 {
 	int i, j;
 	struct stats_filesystem *sfc, *sfm;
-	int unit = -1;
+	int unit = NO_UNIT;
 
 	if (DISPLAY_UNIT(flags)) {
 		/* Default values unit is B */
-		unit = 1;
+		unit = UNIT_BYTE;
 	}
 
 	if (dis) {
@@ -2668,16 +2669,16 @@ __print_funct_t stub_print_filesystem_stats(struct activity *a, int curr, int di
 			  unit < 0 ? (double) sfc->f_bfree / 1024 / 1024 : (double) sfc->f_bfree,
 			  unit < 0 ? (double) (sfc->f_blocks - sfc->f_bfree) / 1024 / 1024 :
 				     (double) (sfc->f_blocks - sfc->f_bfree));
-		cprintf_pc(2, 9, 2,
+		cprintf_pc(DISPLAY_UNIT(flags), 2, 9, 2,
 			   /* f_blocks is not zero. But test it anyway ;-) */
 			   sfc->f_blocks ? SP_VALUE(sfc->f_bfree, sfc->f_blocks, sfc->f_blocks)
 			   : 0.0,
 			   sfc->f_blocks ? SP_VALUE(sfc->f_bavail, sfc->f_blocks, sfc->f_blocks)
 			   : 0.0);
-		cprintf_u64(-1, 2, 9,
+		cprintf_u64(NO_UNIT, 2, 9,
 			    (unsigned long long) sfc->f_ffree,
 			    (unsigned long long) (sfc->f_files - sfc->f_ffree));
-		cprintf_pc(1, 9, 2,
+		cprintf_pc(DISPLAY_UNIT(flags), 1, 9, 2,
 			   sfc->f_files ? SP_VALUE(sfc->f_ffree, sfc->f_files, sfc->f_files)
 			   : 0.0);
 		cprintf_in(IS_STR, " %s\n",
@@ -2767,7 +2768,7 @@ __print_funct_t print_fchost_stats(struct activity *a, int prev, int curr,
 			break;
 
 		printf("%-11s", timestamp[curr]);
-		cprintf_f(-1, 4, 9, 2,
+		cprintf_f(NO_UNIT, 4, 9, 2,
 			  S_VALUE(sfcp->f_rxframes, sfcc->f_rxframes, itv),
 			  S_VALUE(sfcp->f_txframes, sfcc->f_txframes, itv),
 			  S_VALUE(sfcp->f_rxwords,  sfcc->f_rxwords,  itv),
@@ -2832,7 +2833,7 @@ __print_funct_t print_softnet_stats(struct activity *a, int prev, int curr,
 				cprintf_in(IS_INT, " %7d", "", i - 1);
 			}
 
-			cprintf_f(-1, 5, 9, 2,
+			cprintf_f(NO_UNIT, 5, 9, 2,
 				  S_VALUE(ssnp->processed,    ssnc->processed,    itv),
 				  S_VALUE(ssnp->dropped,      ssnc->dropped,      itv),
 				  S_VALUE(ssnp->time_squeeze, ssnc->time_squeeze, itv),
